using Contracts.DTO;
using Contracts.SearchModels;
using Contracts.Services;
using Contracts.ViewModels;
using Microsoft.AspNetCore.Mvc;

namespace Controllers.Controllers
{
    [ApiController]
    [Route("api/[controller]")]
    public class UserController : ControllerBase
    {
        private readonly IUserService _userService;

        public UserController(IUserService userService)
        {
            _userService = userService;
        }

        [HttpGet]
        public async Task<ActionResult<UserViewModel>> GetUser([FromQuery] UserSearch search)
        {
            var user = await _userService.GetDetails(search);

            return Ok(user);
        }

        [HttpPut]
        public async Task<ActionResult<UserViewModel>> UpdateUser([FromBody] UserDto user)
        {
            var updatedUser = await _userService.UpdateUserData(user);

            return Ok(updatedUser);
        }

        [HttpDelete]
        public async Task<ActionResult<UserViewModel>> DeleteUser([FromQuery] UserSearch search)
        {
            var deletedUser = await _userService.Delete(search);

            return Ok(deletedUser);
        }
    }
}
